@@ -1,19 +1,14 @@
 class DrawMethod < NodeEntityAbstract
 
-  has_many :draw_method_attributes, :dependent => :destroy
+  has_many :draw_method_options, :dependent => :destroy
 
   before_save :check_name
   after_save :update_yml
   after_update :update_yml
 
-  protected
 
-  def check_name
-    dm = DrawMethod.find(:first, :conditions=>["name=?",node.name], :user=>:all)
-    if dm && dm != self
-      errors.add("name", "must be uniq")
-      return false
-    end
+  def to_xml(opts={})
+    super(opts.merge(:include => :draw_method_options))
   end
 
   def update_yml
@@ -28,7 +23,7 @@ class DrawMethod < NodeEntityAbstract
     h[:ggraph] = self.ggraph if self.ggraph
     h[:setting_html] = self.setting_html if self.setting_html
     ary = Array.new
-    draw_method_attributes.each{|da|
+    draw_method_options.each{|da|
       h2 = Hash.new
       h2[:name] = da.name
       h2[:value_type] = da.value_type.name
@@ -37,12 +32,22 @@ class DrawMethod < NodeEntityAbstract
       h2[:parser] = da.parser
       ary.push h2
     }
-    h[:attributes] = ary if ary.length > 0
+    h[:options] = ary
     yml = add_prefix(self.path)+".yml"
     File.open(yml,"w"){|file|
       file.print h.to_yaml
     }
   end
 
+  protected
+
+  def check_name
+    dm = DrawMethod.find(:first, :conditions=>["name=?",node.name], :user=>:all)
+    if dm && dm != self
+      errors.add("name", "must be uniq")
+      return false
+    end
+  end
+
 
 end
