@@ -12,12 +12,45 @@ class Function < NodeEntityAbstract
     result = ""
     function_arguments.length.times{|i|
       arg = function_arguments[i]
-      result += " arg#{i} = arg#{i}.#{to_type(arg.name)}\n"
+      result << " arg#{i} = arg#{i}.#{to_type(arg.name)}\n"
     }
-    result += script
+    result << script
     return result
   end
 
+  def update_yml
+    return if default
+    h = Hash.new
+    h[:name] = self.name
+    h[:description] = self.description
+    h[:nvars] = self.nvars
+    h[:script] = self.script
+    h[:setting_html] = self.setting_html
+    ary = Array.new
+    function_arguments.each{|fa|
+      h2 = Hash.new
+      h2[:description] = fa.description
+      h2[:value_type] = fa.value_type.name
+      h2[:default] = fa.default
+      h2[:position] = fs.position
+      ary.push h2
+    }
+    h[:arguments] = ary
+    ary = Array.new
+    function_outputs.each{|fo|
+      h2 = Hash.new
+      h2[:name] = fo.name
+      h2[:subscript] = fo.subscript
+      h2[:description] = fo.description
+      ary.push h2
+    }
+    h[:outputs] = ary
+    yml = add_prefix(self.path)+".yml"
+    File.open(yml,"w"){|file|
+      file.print h.to_yaml
+    }
+  end
+
   protected
 
   def check_name
@@ -28,37 +61,6 @@ class Function < NodeEntityAbstract
     end
   end
 
-  def update_yml
-    return if default
-    h = Hash.new
-    h[:name] = self.name
-    h[:description] = self.description
-    h[:nvars] = self.nvars
-    h[:script] = self.script
-    ary = Array.new
-    function_arguments.each{|fa|
-      h2 = Hash.new
-      h2[:description] = fa.description
-      h2[:value_type] = fa.value_type.name
-      h2[:default] = fa.default
-      ary.push h2
-    }
-    h[:arguments] = ary if ary.length > 0
-    ary = Array.new
-    function_outputs.each{|fo|
-      h2 = Hash.new
-      h2[:name] = fo.name
-      h2[:subscript] = fo.subscript
-      h2[:description] = fo.description
-      ary.push h2
-    }
-    h[:outputs] = ary if ary.length > 0
-    yml = add_prefix(self.path)+".yml"
-    File.open(yml,"w"){|file|
-      file.print h.to_yaml
-    }
-  end
-
   def to_type(type)
     case type.value_type
     when "int"
