@@ -7,10 +7,15 @@ class KnowledgeFigure < ActiveRecord::Base
   alias :__image__ :image
   def image
     image = __image__
-    raise("#{path} is a GPhys, not a figure.") if image.gphysizable?
+p "knowledge_figure.rb / image: #{image}"
+    raise("#{path} is a GPhys, not a figure.") if image.respond_to?("gphysizable") && image.gphysizable?
     image
   end
 
+  def link_of_figure
+    self.image_path
+  end
+
 end
 
 
