@@ -5,6 +5,14 @@ def add_conditions(conditions, new_condition, andor="AND")
     conditions[0] += " #{andor} (#{new_condition})"
   elsif String === conditions
     conditions += " #{andor} (#{new_condition})"
+  elsif Hash === conditions
+    new_cond = Array.new
+    conditions = conditions.each{|k,v|
+      new_cond[0] = new_cond[0] || ""
+      new_cond[0] += "#{k}=?"
+      new_cond << v
+    }
+    conditions = new_cond
   else
     raise "bug"
   end
@@ -29,3 +37,12 @@ def boolean_condition(name)
   end
 end
 
+def temp_storage 
+  if ActiveRecord::Base.connection.adapter_name=="MySQL"
+    #return "ENGINE=MEMORY"
+    return "ENGINE=InnoDB"
+  else
+    return ""
+    end
+end
+
