@@ -1,5 +1,5 @@
 require File.dirname(__FILE__) + '/../test_helper'
-require File.expand_path(File.dirname(__FILE__) + "/../../lib/narray_yaml")
+require File.expand_path(File.dirname(__FILE__) + "/../../lib/narray_gfdnavi")
 
 class VariableTest < Test::Unit::TestCase
   fixtures :variables, :directories, :nodes, :users, :groups
